<?php

/**
 * @file
 * Administrative page callbacks for the hapity module.
 */

/**
 * Generates the settings form for the hapity module.
 *
 * @param string $op
 *   Default value is NULL; determines what are the permissions of the current
 *   user on the hapity.
 *
 * @return string
 *   The output, which contains the HTML code for the settings form generated by
 *   drupal_get_form() function.
 */
function hapity_settings_page($op = NULL) {
  $output = drupal_get_form('hapity_general_settings_form');
  return $output;
}

/**
 * Define a form to edit the page header and descriptive text.
 *
 * @return array
 *   The general settings form code stored in the $form variable, before
 *   converted to HTML.
 */
function hapity_general_settings_form($form) {
  $form['hapity_auth_key'] = array(
    '#type' => 'textfield',
    '#title' => t("Hapity Plugin's ID"),
    '#default_value' => variable_get('hapity_auth_key', ''),
  );

  $form['hapity_post_enable'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enabled?'),
    '#default_value' => variable_get('hapity_post_enable', '1'),
  );

  return system_settings_form($form);
}

/**
 * Validate for general settings form.
 */
function hapity_general_settings_form_validate($form, &$form_state) {
  $hapity_auth_key = $form_state['values']['hapity_auth_key'];
  _hapity_authenticate_key($hapity_auth_key);
}

/**
 * Rebuilds the menu to account for adjustments to the hapity_path variable.
 */
function hapity_general_settings_form_submit($form, &$form_state) {
  menu_rebuild();
}

/**
 * Helper function to send call back URL to Hapity.
 *
 * @param string $auth_key
 *   The Auth kay.
 */
function _hapity_authenticate_key($auth_key) {
  global $base_url;
  $callback_url = $base_url . '/hapity-callback';
  $auth_url = 'https://www.hapity.com/api/validate_key/?auth_key=' . $auth_key . '&type=drupal&url=' . $callback_url;
  $response = drupal_http_request($auth_url);
  $response_data = json_decode($response->data);
  if ($response_data->status == 'success') {
    drupal_set_message(t("Configurations saved successfully"));
  }
  else {
    drupal_set_message(t("Sorry there is a problem! please check your pulgin key"), 'error');
  }
}
